allow dabase update with pushlist
It can push several items at same time
Change-Id: I5ffbcb0c112a0c539862901ec5659ffca768316d
Signed-off-by: tierno <alfonso.tiernosepulveda@telefonica.com>
diff --git a/osm_common/dbmongo.py b/osm_common/dbmongo.py
index e40d0e4..0784985 100644
--- a/osm_common/dbmongo.py
+++ b/osm_common/dbmongo.py
@@ -362,7 +362,8 @@
except Exception as e: # TODO refine
raise DbException(e)
- def set_one(self, table, q_filter, update_dict, fail_on_empty=True, unset=None, pull=None, push=None):
+ def set_one(self, table, q_filter, update_dict, fail_on_empty=True, unset=None, pull=None, push=None,
+ push_list=None):
"""
Modifies an entry at database
:param table: collection or table
@@ -376,6 +377,8 @@
if exist in the array is removed. If not exist, it is ignored
:param push: Plain dictionary with the content to be appended to an array. It is a dot separated keys and value
is appended to the end of the array
+ :param push_list: Same as push but values are arrays where each item is and appended instead of appending the
+ whole array
:return: Dict with the number of entries modified. None if no matching is found.
"""
try:
@@ -386,8 +389,10 @@
db_oper["$unset"] = unset
if pull:
db_oper["$pull"] = pull
- if push:
- db_oper["$push"] = push
+ if push or push_list:
+ db_oper["$push"] = push or {}
+ if push_list:
+ db_oper["$push"].update({k: {"$each": v} for k, v in push_list.items()})
with self.lock:
collection = self.db[table]
@@ -401,7 +406,7 @@
except Exception as e: # TODO refine
raise DbException(e)
- def set_list(self, table, q_filter, update_dict, unset=None, pull=None, push=None):
+ def set_list(self, table, q_filter, update_dict, unset=None, pull=None, push=None, push_list=None):
"""
Modifies al matching entries at database
:param table: collection or table
@@ -411,8 +416,10 @@
ignored. If not exist, it is ignored
:param pull: Plain dictionary with the content to be removed from an array. It is a dot separated keys and value
if exist in the array is removed. If not exist, it is ignored
- :param push: Plain dictionary with the content to be appended to an array. It is a dot separated keys and value
- is appended to the end of the array
+ :param push: Plain dictionary with the content to be appended to an array. It is a dot separated keys, the
+ single value is appended to the end of the array
+ :param push_list: Same as push but values are arrays where each item is and appended instead of appending the
+ whole array
:return: Dict with the number of entries modified
"""
try:
@@ -423,8 +430,10 @@
db_oper["$unset"] = unset
if pull:
db_oper["$pull"] = pull
- if push:
- db_oper["$push"] = push
+ if push or push_list:
+ db_oper["$push"] = push or {}
+ if push_list:
+ db_oper["$push"].update({k: {"$each": v} for k, v in push_list.items()})
with self.lock:
collection = self.db[table]
rows = collection.update_many(self._format_filter(q_filter), db_oper)